#ifndef UTILS_INC
#define UTILS_INC

#include <syslog.h>
#include "compiler.h"
#include "def.h"


enum fg_colors {
	RED = 31,
	GREEN,
	YELLOW,
	BLUE,
	VIOLET, /* not used */
	AZURE
};

void color_printf(int level, enum fg_colors color, char *format, ...) __format(printf, 3, 4);
char *get_param_value(const char *pname, struct paramlist *pl);
int add_param(struct paramlist **top, const char *param, const char *value); 
int add_intparam(struct paramlist **top, const char *param, int value); 
void paramlist2strlists(struct paramlist *params, char *field_list,
		char *value_list, char *middle_str_f, char *end_str_f,
		char *middle_str_v, char *end_str_v);
void paramlist2keyvaluelist(struct paramlist *params, char *kvlist); 
inline int anulltoi(const char *str);
struct tariff *Tariff(int id, char *week_days); 
struct account *Account(int id, double balance, double credit, int blocked, enum accountType type, int client_id, int group_id); 
union abonent *Abonent(int client_id, int group_id, struct clientslist *members, enum abonentType type); 
void free_serviceslist(struct serviceslist *sl);
void free_paramlist(struct paramlist *pl);
void free_clientslist(struct clientslist *ul); 
void free_abonentslist(struct abonentslist *al); 
void free_abonent(union abonent *ab, enum abonentType type);
void free_abonent_ptrs(union abonent *ab, enum abonentType type);
void free_client(struct client *client);
void free_client_ptrs(struct client *client);
void free_clientgroup(struct clientgroup *clientgroup);
void free_clientgroup_ptrs(struct clientgroup *clientgroup);
int load_library(const char *libtype, const char *libname, void **libhandle);

#define debug(format...) color_printf(LOG_INFO, GREEN, format)
#define notice(format...) color_printf(LOG_NOTICE, BLUE, format)
#define info(format...) color_printf(LOG_INFO, AZURE, format)
#define warn(format...) color_printf(LOG_WARNING, YELLOW, format)
#define err(format...) color_printf(LOG_ERR, RED, format)

#endif

